@@ -342,6 +342,13 @@ read_dsgwconfig( char *filename, char *locsuffix, int templatesonly, int binddnf
 	    } else {
 	      gc->gc_aimpresence = 0;
 	    }
+	} else if ( strcasecmp( cargv[0], "have-aim-schema" ) == 0 ) {
+	    if ( templatesonly ) continue;
+	    if (cargc < 2 || strcasecmp(cargv[1], "true") == 0) {
+	      gc->gc_haveaimschema = 1;
+	    } else {
+	      gc->gc_haveaimschema = 0;
+	    }
 	} else if ( strcasecmp( cargv[0], "baseurl" ) == 0 ) {
 	    if ( templatesonly ) continue;
 	    if ( cargc < 2 ) {
@@ -350,19 +357,50 @@ read_dsgwconfig( char *filename, char *locsuffix, int templatesonly, int binddnf
 		continue;
 	    }
 	    gc->gc_baseurl = dsgw_ch_strdup( cargv[ 1 ]);
-	    if (( rc = ldap_url_parse( gc->gc_baseurl, &ludp )) != 0 ) {
+	    if (( rc = dsgw_ldap_url_parse( gc->gc_baseurl, &ludp, 0, NULL )) != 0 ) {
 		switch ( rc ) {
-		case LDAP_URL_ERR_NODN:
-		    adderr( gc, XP_GetClientStr(DBT_badUrlProvidedForBaseurlDirectiv_), filename, lineno );
-		    break;
 		case LDAP_URL_ERR_MEM:
 		    dsgw_error( DSGW_ERR_NOMEMORY,
 			    XP_GetClientStr(DBT_parsingBaseurlDirective_),
 			    DSGW_ERROPT_EXIT, 0, NULL );
 		    break;
+#if defined(USE_OPENLDAP)
+		case LDAP_URL_ERR_BADSCHEME:
+		    adderr( gc, XP_GetClientStr(DBT_doesNotBeginWLDAP_),
+		            filename, lineno );
+		    break;
+		case LDAP_URL_ERR_BADENCLOSURE:
+		    adderr( gc, XP_GetClientStr(DBT_missingTrailingGT_),
+		            filename, lineno );
+		    break;
+		case LDAP_URL_ERR_BADURL:
+		    adderr( gc, XP_GetClientStr(DBT_notValidLDAPURL),
+		            filename, lineno );
+		    break;
+		case LDAP_URL_ERR_BADHOST:
+		    adderr( gc, XP_GetClientStr(DBT_hostnamePartOfURL_),
+		            filename, lineno );
+		    break;
+		case LDAP_URL_ERR_BADATTRS:
+		    adderr( gc, XP_GetClientStr(DBT_attributeListNotFormatted_),
+		            filename, lineno );
+		    break;
+		case LDAP_URL_ERR_BADFILTER:
+		    adderr( gc, XP_GetClientStr(DBT_searchFilterNotCorrect),
+		            filename, lineno );
+		    break;
+		case LDAP_URL_ERR_BADEXTS:
+		    adderr( gc, XP_GetClientStr(DBT_extensionsNotSpecified_),
+		            filename, lineno );
+		    break;
+#else /* !USE_OPENLDAP */
+		case LDAP_URL_ERR_NODN:
+		    adderr( gc, XP_GetClientStr(DBT_badUrlProvidedForBaseurlDirectiv_), filename, lineno );
+		    break;
 		case LDAP_URL_ERR_NOTLDAP:
 		    adderr( gc, XP_GetClientStr(DBT_badUrlProvidedForBaseurlDirectiv_1), filename, lineno );
 		    break;
+#endif
 		}
 	    } else {
 		gc->gc_ldapserver = ludp->lud_host;
@@ -372,9 +410,19 @@ read_dsgwconfig( char *filename, char *locsuffix, int templatesonly, int binddnf
 		} else {
 		    gc->gc_ldapsearchbase = ludp->lud_dn;
 		}
-		if (( ludp->lud_options & LDAP_URL_OPT_SECURE ) != 0 ) {
+#if defined(USE_OPENLDAP)
+		if ( (strcmp( ludp->lud_scheme, "ldaps" )) == 0 ) {
 		    gc->gc_ldapssl = 1;
+		} else {
+		    gc->gc_ldapssl = 0;
 		}
+#else
+		if ( ludp->lud_options & LDAP_URL_OPT_SECURE ) {
+		    gc->gc_ldapssl = 1;
+		} else {
+		    gc->gc_ldapssl = 0;
+		}
+#endif
 	    }
 
 	} else if ( strcasecmp( cargv[0], "template" ) == 0 ) {
@@ -742,6 +790,10 @@ read_dsgwconfig( char *filename, char *locsuffix, int templatesonly, int binddnf
 	}
     }
 
+    if (!gc->gc_haveaimschema) {
+	gc->gc_aimpresence = 0; /* can't have aim presence without aim schema */
+    }
+
     if ( gc == NULL || gc->gc_configerr > 0 ) {
 	dsgw_error( DSGW_ERR_BADCONFIG, ( gc->gc_configerrstr == NULL ) ?
 		"" : gc->gc_configerrstr, DSGW_ERROPT_EXIT, 0, NULL );
