@@ -176,7 +176,7 @@ emit_file (char* filename, struct ldap_searchobj* sop)
  * *after* the onSumbit handler executes, which is unfortunate.
  */
 			    "    if (sform.searchstring.value == '') {\n");
-		dsgw_emit_alert ("searchStringFrame", NULL,
+		dsgw_emit_alert ("searchStringFrame", NULL, "%s",
 				 XP_GetClientStr (DBT_youDidNotSupplyASearchString_));
 		dsgw_emits ("         return false;\n"
 			    "    }\n"
