@@ -53,8 +53,7 @@ BEGIN_STR(dsgw)
 	ResDef( DBT_unableToWriteTemplateIndexFile_, 20, "Unable to write template index file." )/*extracted from error.c*/
 	ResDef( DBT_unableToOpenTemplateIndexFile_, 21, "Unable to open template index file." )/*extracted from error.c*/
 	ResDef( DBT_unableToReadDirectory_, 22, "Unable to read directory." )/*extracted from error.c*/
-	ResDef( DBT_ldapSslInitializationFailedCheck_, 23, "LDAP SSL initialization failed (check the security path)." )/*extracted from error.c*/
-	ResDef( DBT_forTheUsersAndGroupsFormsToWorkO_, 24, "For the Users and Groups forms to work over SSL, you or your server administrator needs to activate SSL for this Administration Server.  The Encryption|On/Off page can be used to do so. " )/*extracted from error.c*/
+	ResDef( DBT_ldapSslInitializationFailedCheck_, 23, "LDAP SSL initialization failed (check the security path in the dsgw configuration)." )/*extracted from error.c*/
 	ResDef( DBT_authenticationCredentialsNotFoun_, 25, "Authentication credentials not found in authentication database." )/*extracted from error.c*/
 	ResDef( DBT_errorRetrievingDataFromTheAuthen_, 26, "Error retrieving data from the authentication database." )/*extracted from error.c*/
 	ResDef( DBT_yourAuthenticationCredentialsHav_, 27, "Your authentication credentials have expired." )/*extracted from error.c*/
@@ -469,6 +468,18 @@ BEGIN_STR(dsgw)
             "opener.top.close();" )
     ResDef( DBT_confirmValue5, 424,
             "opener.confirmedForm.submit();" )
+    
+    ResDef( DBT_doesNotBeginWLDAP_, 425, 
+            "does not begin with ldap://, ldaps://, or ldapi://;" )
+    ResDef( DBT_missingTrailingGT_, 426, "missing trailing '>' in enclosure;" )
+    ResDef( DBT_notValidLDAPURL, 427, "not a valid LDAP URL;" )
+    ResDef( DBT_hostnamePartOfURL_, 428,
+            "hostname part of url is not valid or not given;" )
+    ResDef( DBT_attributeListNotFormatted_, 429,
+            "attribute list not formatted correctly or missing;" )
+    ResDef( DBT_searchFilterNotCorrect, 430, "search filter not correct;" )
+    ResDef( DBT_extensionsNotSpecified_, 431,
+            "extensions not specified correctly;" )
 
 END_STR(dsgw)
 
