@@ -139,7 +139,7 @@ int main(int argc, char *argv[] )
 	"    var selvalue = sel.options[sel.selectedIndex].value;\n"
 	"    var lt = f.listtemplate;\n"
 	"    if ( f.searchstring.value.length == 0 ) {\n");
-    dsgw_emit_alert( "controlFrame", NULL, XP_GetClientStr( DBT_noSearchStringWasProvidedPleaseT_ ));
+    dsgw_emit_alert( "controlFrame", NULL, "%s", XP_GetClientStr( DBT_noSearchStringWasProvidedPleaseT_ ));
     dsgw_emits(
 	"	return false;\n"
 	"    }\n"
@@ -323,7 +323,7 @@ int main(int argc, char *argv[] )
 		       "CONFIRMVALUE1",
 		       NULL /* no */,
 		       XP_GetClientStr(DBT_discardChangesWindow_), 1,
-		       XP_GetClientStr(DBT_discardChanges_));
+		       "%s", XP_GetClientStr(DBT_discardChanges_));
     dsgw_emits (
 	"    }\n"
 	"}\n"
