@@ -27,13 +27,9 @@ static void do_autherror( int rc, char *msg, char *lderrtxt,
 	int ommitclosebutton );
 
 
-int main( argc, argv, env )
-    int		argc;
-    char	*argv[];
+int main( int argc, char *argv[] )
 {
-    int		reqmethod;
-
-    reqmethod = dsgw_init( argc, argv,  DSGW_METHOD_POST );
+    (void)dsgw_init( argc, argv,  DSGW_METHOD_POST );
 
     post_request();
 
