@@ -114,7 +114,7 @@ post_request()
     }
 
     if ( dsgw_init_ldap( &ld, NULL, 0, 0) != DSGW_BOUND_ASUSER ) {
-	dsgw_emitf( XP_GetClientStr(DBT_warningNoAuthenticationContinuin_) );
+	dsgw_emitf( "%s", XP_GetClientStr(DBT_warningNoAuthenticationContinuin_) );
     }
 
     if ( !quiet ) {
@@ -589,7 +589,7 @@ entry_modify_or_add( LDAP *ld, char *dn, int add, int *pwdchangedp )
 	} else {	/* no changes -- just report success */
 	    lderr = LDAP_SUCCESS;
 	    if ( !quiet ) {
-		dsgw_emitf( XP_GetClientStr(DBT_PSuccessfullyEditedEntryYourChan_) );
+		dsgw_emitf("%s", XP_GetClientStr(DBT_PSuccessfullyEditedEntryYourChan_) );
 	    }
 	}
     } else { 
@@ -614,9 +614,9 @@ entry_modify_or_add( LDAP *ld, char *dn, int add, int *pwdchangedp )
 			if ( lderr == LDAP_SUCCESS ) {
 				if ( !quiet ) {
 				if ( add ) {
-					dsgw_emitf( XP_GetClientStr(DBT_PSuccessfullyAddedEntryN_) );
+					dsgw_emitf( "%s", XP_GetClientStr(DBT_PSuccessfullyAddedEntryN_) );
 				} else {
-					dsgw_emitf( XP_GetClientStr(DBT_PSuccessfullyEditedEntryYourChan_) );
+					dsgw_emitf( "%s", XP_GetClientStr(DBT_PSuccessfullyEditedEntryYourChan_) );
 				}
 				}
 			} else {
@@ -654,7 +654,7 @@ entry_delete( LDAP *ld, char *dn )
     dsgw_emitf( "<FONT SIZE=+1>\n" );
     if (( lderr = ldap_delete_ext_s( ld, dn, NULL, NULL )) == LDAP_SUCCESS ) {
 	if ( !quiet ) {
-	    dsgw_emitf( XP_GetClientStr(DBT_PSuccessfullyDeletedEntryN_) );
+	    dsgw_emitf( "%s", XP_GetClientStr(DBT_PSuccessfullyDeletedEntryN_) );
 	}
     } else {
 	(void)dsgw_ldap_get_lderrno( ld, NULL, &errmsg );
@@ -673,7 +673,7 @@ entry_modrdn( LDAP *ld, char *dn, char *newrdn, int deleteoldrdn )
     char	*errmsg = NULL;
 
     if ( verbose ) {
-	dsgw_emitf( XP_GetClientStr(DBT_PreTheNewNameForTheEntryIsSNPreH_),
+	dsgw_emitf( "%s %s", XP_GetClientStr(DBT_PreTheNewNameForTheEntryIsSNPreH_),
 		newrdn );
     }
 
@@ -681,7 +681,7 @@ entry_modrdn( LDAP *ld, char *dn, char *newrdn, int deleteoldrdn )
     if (( lderr = ldap_rename_s( ld, dn, newrdn, NULL, deleteoldrdn, NULL, NULL ))
 	    == LDAP_SUCCESS ) {
 	if ( !quiet ) {
-	    dsgw_emitf( XP_GetClientStr(DBT_PSuccessfullyRenamedEntryN_) );
+	    dsgw_emitf( "%s", XP_GetClientStr(DBT_PSuccessfullyRenamedEntryN_) );
 	}
     } else {
 	(void)dsgw_ldap_get_lderrno( ld, NULL, &errmsg );
