@@ -15,6 +15,47 @@
  * Copyright (C) 2001 Sun Microsystems, Inc. Used by permission.
  * Copyright (C) 2005 Red Hat, Inc.
  * All rights reserved.
+ *
+ * data type struct ldap_filt_list and struct ldap_filt_desc 
+ * are from the file libraries/libldap/ldap-int.h in the Mozilla LDAP C SDK
+ *
+ * Version: MPL 1.1/GPL 2.0/LGPL 2.1
+ * 
+ * The contents of this file are subject to the Mozilla Public License Version 
+ * 1.1 (the "License"); you may not use this file except in compliance with 
+ * the License. You may obtain a copy of the License at 
+ * http://www.mozilla.org/MPL/
+ * 
+ * Software distributed under the License is distributed on an "AS IS" basis,
+ * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
+ * for the specific language governing rights and limitations under the
+ * License.
+ * 
+ * The Original Code is Mozilla Communicator client code, released
+ * March 31, 1998.
+ * 
+ * The Initial Developer of the Original Code is
+ * Netscape Communications Corporation.
+ * Portions created by the Initial Developer are Copyright (C) 1998-1999
+ * the Initial Developer. All Rights Reserved.
+ * 
+ * Contributor(s):
+ * 
+ * Alternatively, the contents of this file may be used under the terms of
+ * either of the GNU General Public License Version 2 or later (the "GPL"),
+ * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
+ * in which case the provisions of the GPL or the LGPL are applicable instead
+ * of those above. If you wish to allow use of your version of this file only
+ * under the terms of either the GPL or the LGPL, and not to allow others to
+ * use your version of this file under the terms of the MPL, indicate your
+ * decision by deleting the provisions above and replace them with the notice
+ * and other provisions required by the GPL or the LGPL. If you do not delete
+ * the provisions above, a recipient may use your version of this file under
+ * the terms of any one of the MPL, the GPL or the LGPL.
+ * 
+ *  Copyright (c) 1994 Regents of the University of Michigan.
+ *  All rights reserved.
+ *
   --- END COPYRIGHT BLOCK ---  */
 /*
  * dsgw.h -- defines for HTTP gateway 
@@ -35,7 +76,14 @@
 #include <ldap.h>
 #include <srchpref.h>
 #include <ssl.h>
+#if !defined(USE_OPENLDAP)
 #include <ldap_ssl.h>
+#endif
+
+/* for re_comp */
+#define _REGEX_RE_COMP
+#include <sys/types.h>
+#include <regex.h>
 
 #if defined( XP_WIN32 )
 
@@ -362,6 +410,15 @@ extern char            *context ;
 #define DSGW_ERR_USERID_MAXLEN_EXCEEDED		52
 #define DSGW_ERR_CHARSET_NOT_SUPPORTED		53
 
+#if defined(USE_OPENLDAP)
+#define DSGW_ERR_BADSCHEME		54
+#define DSGW_ERR_BADENCLOSURE	55
+#define DSGW_ERR_BADURL			56
+#define DSGW_ERR_BADHOST		57
+#define DSGW_ERR_BADATTRS		58
+#define DSGW_ERR_BADFILTER		59
+#define DSGW_ERR_BADEXTS		60
+#endif
 /* Return codes from dsgw_init_ldap() */
 #define	DSGW_BOUND_ASUSER		1
 #define	DSGW_BOUND_ANONYMOUS		2
@@ -533,6 +590,7 @@ typedef struct dsgwconfig_t {
     char	*gc_orgcharturl;        /* http base url for orgchart*/
     char	*gc_orgchartsearchattr; /* Search attribute the orgchart uses*/
     int         gc_aimpresence;         /* enable aim presence*/
+    int         gc_haveaimschema;       /* do we have the AIM schema? */
     dsgwtmpl	*gc_templates;		/* linked list */
     dsgwnewtype *gc_newentrytypes;	/* linked list */
     dsgwloc	*gc_newentrylocs;	/* array of structures */
@@ -566,6 +624,81 @@ typedef struct ldapdb_url_desc {
     char	*ludb_dn;
 } LDAPDBURLDesc;
 
+#if defined(USE_OPENLDAP)
+/* Ported from mozldap */
+/*
+ * Structures, constants, and types for filter utility routines:
+ */
+typedef struct ldap_filt_info {
+    char                  *lfi_filter;
+    char                  *lfi_desc;
+    int                   lfi_scope;      /* LDAP_SCOPE_BASE, etc */
+    int                   lfi_isexact;    /* exact match filter? */
+    struct ldap_filt_info *lfi_next;
+} LDAPFiltInfo;
+
+#define LDAP_FILT_MAXSIZ    1024
+
+typedef struct ldap_filt_list {
+    char                  *lfl_tag;
+    char                  *lfl_pattern;
+    char                  *lfl_delims;
+    struct ldap_filt_info *lfl_ilist;
+    struct ldap_filt_list *lfl_next;
+} LDAPFiltList; /* opaque filter list handle */
+
+typedef struct ldap_filt_desc {
+    LDAPFiltList    *lfd_filtlist;
+    LDAPFiltInfo    *lfd_curfip;
+    LDAPFiltInfo    lfd_retfi;
+    char            lfd_filter[ LDAP_FILT_MAXSIZ ];
+    char            *lfd_curval;
+    char            *lfd_curvalcopy;
+    char            **lfd_curvalwords;
+    char            *lfd_filtprefix;
+    char            *lfd_filtsuffix;
+} LDAPFiltDesc; /* opaque filter desc handle */
+
+/*
+ * UTF-8 routines (should these move into libnls?)
+ */
+/* number of bytes in character */
+int ldap_utf8len( const char* );
+/* find next character */
+char *ldap_utf8next( char* );
+/* find previous character */
+char *ldap_utf8prev( char* );
+/* copy one character */
+int ldap_utf8copy( char* dst, const char* src );
+/* total number of characters */
+size_t ldap_utf8characters( const char* );
+/* get one UCS-4 character, and move *src to the next character */
+unsigned long ldap_utf8getcc( const char** src );
+/* UTF-8 aware strtok_r() */
+char *ldap_utf8strtok_r( char* src, const char* brk, char** next);
+
+/* like isalnum(*s) in the C locale */
+int ldap_utf8isalnum( char* s );
+/* like isalpha(*s) in the C locale */
+int ldap_utf8isalpha( char* s );
+/* like isdigit(*s) in the C locale */
+int ldap_utf8isdigit( char* s );
+/* like isxdigit(*s) in the C locale */
+int ldap_utf8isxdigit(char* s );
+/* like isspace(*s) in the C locale */
+int ldap_utf8isspace( char* s );
+
+#define LDAP_UTF8LEN(s)  ((0x80 & *(unsigned char*)(s)) ?   ldap_utf8len (s) : 1)
+#define LDAP_UTF8NEXT(s) ((0x80 & *(unsigned char*)(s)) ?   ldap_utf8next(s) : ( s)+1)
+#define LDAP_UTF8INC(s)  ((0x80 & *(unsigned char*)(s)) ? s=ldap_utf8next(s) : ++s)
+
+#define LDAP_UTF8PREV(s)   ldap_utf8prev(s)
+#define LDAP_UTF8DEC(s) (s=ldap_utf8prev(s))
+
+#define LDAP_UTF8COPY(d,s) ((0x80 & *(unsigned char*)(s)) ? ldap_utf8copy(d,s) : ((*(d) = *(s)), 1))
+#define LDAP_UTF8GETCC(s) ((0x80 & *(unsigned char*)(s)) ? ldap_utf8getcc (&s) : *s++)
+#define LDAP_UTF8GETC(s) ((0x80 & *(unsigned char*)(s)) ? ldap_utf8getcc ((const char**)&s) : *s++)
+#endif
 
 /* template stuff */
 /* The number of templates defined */
@@ -734,7 +867,8 @@ typedef struct dsgwtmplinfo {
 #define	DSGW_COND_ATTRHASTHISVALUE	"AttributeHasThisValue"
 #define	DSGW_COND_POSTEDFORMVALUE	"PostedFormValue"
 #define	DSGW_COND_DISPLAYORGCHART	"DisplayOrgChart"
-#define	DSGW_COND_DISPLAYAIMPRESENCE    "DisplayAimPresence"
+#define	DSGW_COND_DISPLAYAIMPRESENCE	"DisplayAimPresence"
+#define	DSGW_COND_HAVEAIMSCHEMA			"HaveAimSchema"
 
 /* global variables */
 extern char *progname;		/* set in dsgwutil.c:dsgw_init() */
@@ -788,7 +922,7 @@ char *dsgw_build_urlprefix_ext(int unescaped);
 void dsgw_init_searchprefs( struct ldap_searchobj **solistp );
 void dsgw_addtemplate( dsgwtmpl **tlpp, char *template, int count,
 	char **ocvals );
-dsgwtmpl *dsgw_oc2template( char **ocvals ); 
+dsgwtmpl *dsgw_oc2template( struct berval **ocvals ); 
 void dsgw_remove_leading_and_trailing_spaces( char **sp );
 int dsgw_parse_cookie( char *cookie, char **rndstr, char **dn );
 char *dsgw_getvp( int cginum );
@@ -810,6 +944,7 @@ void dsgw_password_expired_alert( char *binddn );
 time_t dsgw_current_time();
 time_t dsgw_time_plus_sec (time_t l, long r);
 char *dsgw_server_url();
+void dsgw_charray_free( char **vals );
 
 /*
  * in entrydisplay.c
@@ -819,8 +954,8 @@ dsgwtmplinfo *dsgw_display_init( int tmpltype, char *template,
 void dsgw_display_entry( dsgwtmplinfo *tip, LDAP *ld, LDAPMessage *entry,
 	LDAPMessage *attrsonly_entry, char *dn );
 void dsgw_display_done( dsgwtmplinfo *tip, char *dn );
-char *dsgw_mls_convertlines( char *val, char *sep, int *linesp, int emitlines,
-	int quote_html_specials );
+char *dsgw_mls_convertlines( struct berval *val, char *sep, int *linesp, 
+	int emitlines, int quote_html_specials );
 void dsgw_set_searchdesc( dsgwtmplinfo *tip, char*, char*, char*);
 void dsgw_set_search_result( dsgwtmplinfo *tip, int entrycount,
 	char *searcherror, char *lderrtxt );
@@ -917,7 +1052,7 @@ void dsgw_pattern_search( LDAP *ld, char *listtmpl,
         char *filtpattern, char *filtprefix, char *filtsuffix, char *attr,
         char *base, int scope, char *value, unsigned long options );
 void dsgw_ldapurl_search( LDAP *ld, char *ldapurl );
-void dsgw_read_entry( LDAP *ld, char *dn, char **ocvals, char *tmplname,
+void dsgw_read_entry( LDAP *ld, char *dn, struct berval **ocvals, char *tmplname,
 	char **attrs, unsigned long options );
 int dsgw_ldap_entry_exists( LDAP *ld, char *dn, char **matchedp,
 	unsigned long erropts );
@@ -928,6 +1063,14 @@ int dsgw_dn_cmp( char *dn1, char *dn2 );
 int dsgw_is_dnparent( char *dn1, char *dn2 );
 char *dsgw_dn_parent( char *dn );
 void dsgw_emit_location_popup( LDAP *ld, int argc, char **argv, int erropts );
+int dsgw_ldap_url_parse(const char *url, LDAPURLDesc **ludpp, int require_dn, int *secure);
+char **dsgw_ldap_explode_rdn(const char *rdn, int notypes);
+char **dsgw_ldap_explode_dn(const char *dn, int notypes);
+int dsgw_ldap_get_lderrno(LDAP *ld, char **m, char **s);
+int dsgw_ldap_create_filter( char *filtbuf, unsigned long buflen, char *pattern, char *prefix, char *suffix, char *attr, char *value, char **valwords );
+char **dsgw_ldap_get_values(LDAP *ld, LDAPMessage *entry, const char *attrtype);
+char *dsgw_ldap_dn2ufn(const char *dn);
+
 
 /*
  * in config.c
@@ -1009,15 +1152,15 @@ int dsgw_quote_emitf (int kind, const char* format, ...)
 typedef int (*strcmp_t) (const char*, const char*);
 strcmp_t dsgw_strcmp (int);
 
-typedef int (*valcmp_t) (const char**, const char**);
+typedef int (*valcmp_t) (const struct berval **, const struct berval **); /* NYA: ??? */
 valcmp_t dsgw_valcmp (int);
 
 extern struct berval* dsgw_strkeygen (int, const char*);
 extern struct berval* dsgw_key_first;
 extern struct berval* dsgw_key_last;
 
-int  LDAP_C LDAP_CALLBACK dsgw_keycmp (void*, const struct berval*, const struct berval*);
-void LDAP_C LDAP_CALLBACK dsgw_keyfree(void*, const struct berval*);
+int dsgw_keycmp(void *, const struct berval *, const struct berval *);
+void dsgw_keyfree(void*, const struct berval*);
 
 /*
  * in vcard.c
@@ -1025,7 +1168,7 @@ void LDAP_C LDAP_CALLBACK dsgw_keyfree(void*, const struct berval*);
 void dsgw_vcard_from_entry( LDAP *ld, char *dn, char *mimetype );
 
 /*
- * utf8compare.c
+ * in utf8compare.c
  */
 int dsgw_utf8casecmp(unsigned char *s0, unsigned char *s1);
 int dsgw_utf8ncasecmp(unsigned char *s0, unsigned char *s1, int n);
@@ -1056,3 +1199,42 @@ dsgw_convert(
 );
 #define DSGW_TO_UTF8 0
 #define DSGW_FROM_UTF8 1
+
+int dsgw_charray_bval_merge( char ***a, struct berval **bvals );
+
+typedef int (DSGW_VALCMP_CALLBACK)(const struct berval **val1p, const struct berval **val2p);
+int dsgw_sort_values(struct berval **vals, valcmp_t cmp);
+
+#if defined(USE_OPENLDAP)
+
+#define LDAP_CONTROL_PWEXPIRED          "2.16.840.1.113730.3.4.4"
+#define LDAP_CONTROL_PWEXPIRING         "2.16.840.1.113730.3.4.5"
+
+/*
+ * Client side sorting callback functions:
+ */
+typedef const struct berval* (LDAP_KEYGEN_CALLBACK)( void *arg, 
+        LDAP *ld, LDAPMessage *entry );
+typedef int (LDAP_KEYCMP_CALLBACK)( void *arg, const struct berval*,
+        const struct berval* );
+typedef void (LDAP_KEYFREE_CALLBACK)( void *arg, const struct berval* );
+typedef int (LDAP_CMP_CALLBACK)( const char *L, const char *R );
+
+typedef struct keycmp {
+    void                 *kc_arg;
+    LDAP_KEYCMP_CALLBACK *kc_cmp;
+} keycmp_t;
+
+typedef struct keything {
+    keycmp_t            *kt_cmp;
+    const struct berval *kt_key;
+    LDAPMessage         *kt_msg;
+} keything_t;
+
+/* sort.c */
+int ldap_keysort_entries(LDAP *ld, LDAPMessage **chain, void *arg, LDAP_KEYGEN_CALLBACK *gen, LDAP_KEYCMP_CALLBACK *cmp, LDAP_KEYFREE_CALLBACK *fre);
+int ldap_sort_entries(LDAP *ld, LDAPMessage **chain, char *attr, LDAP_CMP_CALLBACK *cmp);
+
+/* in dsparse.c */
+int nsldapi_next_line_tokens( char **bufp, long *blenp, char ***toksp );
+#endif /* USE_OPENLDAP */
