@@ -694,7 +694,7 @@ dsgw_addtemplate( dsgwtmpl **tlpp, char *template, int count, char **ocvals )
 
 
 dsgwtmpl *
-dsgw_oc2template( char **ocvals )
+dsgw_oc2template( struct berval **ocvals )
 {
     int			i, j, needcnt, matchcnt;
     dsgwtmpl		*tp;
@@ -702,8 +702,9 @@ dsgw_oc2template( char **ocvals )
     for ( tp = gc->gc_templates; tp != NULL; tp = tp->dstmpl_next ) {
 	needcnt = matchcnt = 0;
 	for ( i = 0; tp->dstmpl_ocvals[ i ] != NULL; ++i ) {
-	    for ( j = 0; ocvals[ j ] != NULL; ++j ) {
-		if ( strcasecmp( ocvals[ j ], tp->dstmpl_ocvals[ i ] ) == 0 ) {
+	    for ( j = 0; ocvals[ j ] && ocvals[ j ]->bv_val; ++j ) {
+		if ( strcasecmp( ocvals[ j ]->bv_val, tp->dstmpl_ocvals[ i ] ) 
+		                                                     == 0 ) {
 		    ++matchcnt;
 		}
 	    }
@@ -986,9 +987,6 @@ dsgw_quote_emptyFrame()
 void 
 dsgw_password_expired_alert( char *dn )
 {
-#ifdef NOTFORNOW
-    char *ufn;
-#endif
     char *encodeddn = dsgw_strdup_escaped( dn );
 
 	dsgw_send_header();
@@ -1048,12 +1046,6 @@ dsgw_password_expired_alert( char *dn )
 	    "\n</TABLE></FORM>\n");
 	dsgw_quotation_end(); dsgw_emits(";\n");
 
-#ifdef NOTFORNOW
-	/* ldap_dn2ufn currently gobbles up 'dc' so don't use it for */
-	/* now */
-	ufn = ldap_dn2ufn( dn );
-#endif
-
 	dsgw_emitf(
 		"// End hiding -->\n"
 		"</SCRIPT>\n"
@@ -1146,3 +1138,44 @@ dsgw_server_url()
   tab-width: 8
   End:
 */
+
+void
+dsgw_charray_free( char **vals )
+{
+    int i;
+
+    if ( vals == NULL )
+        return;
+    for ( i = 0; vals[i] != NULL; i++ )
+        free( vals[i] );
+    free( (char *) vals );
+}
+
+int
+dsgw_charray_bval_merge(     
+    char    ***a,           
+    struct berval **bvals
+)                               
+{                               
+    int i, n, nn;
+                                
+    if ( (a == NULL) || (bvals == NULL) || 
+         (bvals[0] == NULL) || (bvals[0]->bv_val == NULL) )
+        return 0;                   
+                                
+    for ( n = 0; *a != NULL && (*a)[n] != NULL; n++ ) {
+        ;   /* NULL */      
+    }                       
+    nn = ldap_count_values_len( bvals );
+                
+    *a = (char **)dsgw_ch_realloc( (char *) *a, (n + nn + 1) * sizeof(char *) );
+    if ( *a == NULL ) { /* never happens */
+        return -1;
+    }
+        
+    for ( i = 0; i < nn; i++ ) {
+        (*a)[n + i] = dsgw_ch_strdup(bvals[i]->bv_val);
+    }
+    (*a)[n + nn] = NULL;
+    return 0;
+}
