@@ -309,7 +309,9 @@ dsgw_vxprintf (dsgw_producer produce, void* parm,
 	    }
 	}
 	if (aslot == islot) { /* No slot refers to this arg. */
-	    if (va_arg (argl, const char*)); /* Skip over it. */
+	    if (va_arg (argl, const char*)) {
+		; /* Skip over it. */
+	    }
 	} else {
 /*fprintf (stderr, " %i:%i", (int)(aslot-slot), aslot->type);*/
 	    switch (aslot->type) {
