@@ -820,7 +820,7 @@ output_prelude_script( dsgwtmplinfo *tip )
 		        "    else {\n");
 	    dsgw_emit_confirm( NULL, "CONFIRMVALUE3", NULL/*no*/,
 			       XP_GetClientStr(DBT_continueWithoutSavingWindow_), 1,
-			       XP_GetClientStr(DBT_continueWithoutSaving_));
+			       "%s", XP_GetClientStr(DBT_continueWithoutSaving_));
 	    dsgw_emits( "    }\n");
 	    dsgw_emits( "}\n" );
 	}
@@ -839,7 +839,7 @@ output_prelude_script( dsgwtmplinfo *tip )
 		    "    else {\n" );
 	dsgw_emit_confirm( NULL, "CONFIRMVALUE4", NULL/*no*/,
 			   XP_GetClientStr(DBT_discardChangesWindow_), 1,
-			   XP_GetClientStr(DBT_discardChanges_));
+			   "%s", XP_GetClientStr(DBT_discardChanges_));
 	dsgw_emits( "    }\n}\n" );
 
 	/* set unload handler to catch unsaved changes */
@@ -2527,6 +2527,7 @@ do_searchdesc( dsgwtmplinfo *tip, int argc, char** argv)
 	    : ((tip->dsti_options & DSGW_DISPLAY_OPT_CUSTOM_SEARCHDESC)
 	       ? DBT_Found0Entries_
 	       : DBT_Found0EntriesWhere_);
+	break;
       case 1:
 	fmt = opt & 1
 	    ? ((tip->dsti_options & DSGW_DISPLAY_OPT_CUSTOM_SEARCHDESC)
@@ -2535,6 +2536,7 @@ do_searchdesc( dsgwtmplinfo *tip, int argc, char** argv)
 	    : ((tip->dsti_options & DSGW_DISPLAY_OPT_CUSTOM_SEARCHDESC)
 	       ? DBT_Found1Entry_
 	       : DBT_Found1EntryWhere_);
+	break;
       default:
 	fmt = opt & 1
 	    ? ((tip->dsti_options & DSGW_DISPLAY_OPT_CUSTOM_SEARCHDESC)
@@ -2543,6 +2545,7 @@ do_searchdesc( dsgwtmplinfo *tip, int argc, char** argv)
 	    : ((tip->dsti_options & DSGW_DISPLAY_OPT_CUSTOM_SEARCHDESC)
 	       ? DBT_FoundEntries_
 	       : DBT_FoundEntriesWhere_);
+	break;
     }
     {
 	auto char* format = XP_GetClientStr (fmt);
