@@ -79,8 +79,6 @@ static struct dsgwerr dsgw_errs[] = {
         DBT_unableToReadDirectory_ },
     { DSGW_ERR_SSLINIT,
         DBT_ldapSslInitializationFailedCheck_ },
-    { DSGW_ERR_NOSECPATH,
-        DBT_forTheUsersAndGroupsFormsToWorkO_ },
     { DSGW_CKDB_KEY_NOT_PRESENT,
         DBT_authenticationCredentialsNotFoun_ },
     { DSGW_CKDB_DBERROR,
@@ -146,6 +144,29 @@ static struct dsgwerr dsgw_errs[] = {
     { DSGW_ERR_CHARSET_NOT_SUPPORTED,
 		/* "The charset %s is not supported" */
 		DBT_theCharsetIsNotSupported },
+#if defined(USE_OPENLDAP)
+    { DSGW_ERR_BADSCHEME,
+		/* "does not begin with ldap://, ldaps://, or ldapi://" */
+	    DBT_doesNotBeginWLDAP_ },
+    { DSGW_ERR_BADENCLOSURE,
+		/* "missing trailing '>' in enclosure" */
+	    DBT_missingTrailingGT_ },
+    { DSGW_ERR_BADURL,
+		/* "not a valid LDAP URL */
+	    DBT_notValidLDAPURL },
+    { DSGW_ERR_BADHOST,
+		/* "hostname part of url is not valid or not given" */
+	    DBT_hostnamePartOfURL_ },
+    { DSGW_ERR_BADATTRS,
+		/* "attribute list not formatted correctly or missing" */
+	    DBT_attributeListNotFormatted_ },
+    { DSGW_ERR_BADFILTER,
+		/* "search filter not correct" */
+	    DBT_searchFilterNotCorrect },
+    { DSGW_ERR_BADEXTS,
+		/* "extensions not specified correctly" */
+	   DBT_extensionsNotSpecified_ },
+#endif
 };
 #define DSGW_ERROR_CNT	( sizeof( dsgw_errs ) / sizeof( struct dsgwerr ))
 
