@@ -75,7 +75,7 @@ ldap_keysort_entries(
     LDAP_KEYCMP_CALLBACK  *cmp,
     LDAP_KEYFREE_CALLBACK *fre)
 {
-	size_t		count, i;
+	int		count, i;
 	keycmp_t	kc = {0};
 	keything_t	**kt;
 	LDAPMessage	*e, *last;
@@ -129,8 +129,12 @@ ldap_keysort_entries(
 		LDAPMessage *tmp;
 		/* delete (unlink) the message from its unsorted place in the chain */
 		tmp = ldap_delete_result_entry(chain, kt[i-1]->kt_msg);
+#if defined(DEBUG) || defined(FORCE_PR_ASSERT)
 		PR_ASSERT(tmp != NULL); /* should be in the list */
 		PR_ASSERT(tmp == kt[i]->kt_msg); /* should return a pointer into the chain list */
+#else
+		(void)tmp; /* eliminate compiler warning */
+#endif
 		/* ldap_add_result_entry adds the msg/entry to the front of the list */
 		/* so we have to add them backwards to preserve the sorted order */
 		ldap_add_result_entry(chain, kt[i-1]->kt_msg);
