@@ -1,20 +1,20 @@
 #!/bin/sh
 
 testdir="$1"
-hostname=vmhost.testdomain.com
+hostname=${HOSTNAME:-vmhost.testdomain.com}
 sroot=${SROOT:-/home/$USER/dsol}
-secdir=/home/$USER/save
-port=1300
+secdir=${SECDIR:-/home/$USER/save}
+port=${PORT:-1300}
 secport=`expr $port + 1`
-rootdn="cn=directory manager"
-rootpw=password
+rootdn=${ROOTDN:-"cn=directory manager"}
+rootpw=${ROOTPW:-password}
 adminpw=admin
-needdata=1
-usessl=1
+needdata=${NEEDDATA:-1}
+usessl=${USESSL:-1}
 suffix="dc=example,dc=com"
-instance=ds
+instance=${INST:-ds}
 inst=slapd-$instance
-resetdata=1
+resetdata=${RESETDATA:-1}
 
 if [ ! -d $sroot/etc/dirsrv/$inst ] ; then
 $sroot/sbin/setup-ds.pl -s -f - <<EOF
@@ -76,7 +76,7 @@ $sroot/lib/dirsrv/slapd-$instance/start-slapd
 
 fi
 
-if [ "$needdata" ] ; then
+if [ "$needdata" -eq 1 ] ; then
 $sroot/lib/dirsrv/$inst/ldif2db.pl -D "$rootdn" -w "$rootpw" -n userRoot -i $sroot/share/dirsrv/data/Example.ldif
 sleep 10
 fi
@@ -84,7 +84,7 @@ fi
 rm -rf testtmp
 mkdir testtmp
 
-if [ "$usessl" ] ; then
+if [ "$usessl" -eq 1 ] ; then
     ldapurl="ldaps://$hostname:$secport"
     # grab CA cert
     certutil -L -d $sroot/etc/dirsrv/$inst -n "CA certificate" -a > testtmp/cacert.asc
@@ -147,7 +147,7 @@ EOF
 
 #VGPREFIX="valgrind --tool=memcheck --leak-check=yes --suppressions=$HOME/valgrind.supp --num-callers=40 --suppressions=$testdir/valgrind.supp "
 # These are CGI programs - they assume they will run for a very short period of time - they use exit() instead of free() :P
-VGPREFIX="valgrind -q --tool=memcheck --leak-check=no --suppressions=$HOME/valgrind.supp --num-callers=40 --suppressions=$testdir/valgrind.supp "
+VGPREFIX="valgrind -q --trace-children=yes --tool=memcheck --track-origins=yes --read-var-info=yes --leak-check=no --suppressions=$HOME/valgrind.supp --num-callers=50 --suppressions=$testdir/valgrind.supp "
 GDB="gdb -x .gdbinit "
 #DEBUGCMD=VALGRIND
 #DEBUGCMD="$GDB"
@@ -274,12 +274,12 @@ runPostTestsForProg() {
 
 # each prog has a subdir containing the GET/POST args and any other test data
 for prog in $PROGS ; do
-    if [ -n "$resetdata" ] ; then
+    if [ "$resetdata" -eq 1 ] ; then
         $sroot/lib/dirsrv/$inst/ldif2db.pl -D "$rootdn" -w "$rootpw" -n userRoot -i $sroot/share/dirsrv/data/Example.ldif
         sleep 10
     fi
     runGetTestsForProg "$prog"
-    if [ -n "$resetdata" ] ; then
+    if [ "$resetdata" -eq 1 ] ; then
         $sroot/lib/dirsrv/$inst/ldif2db.pl -D "$rootdn" -w "$rootpw" -n userRoot -i $sroot/share/dirsrv/data/Example.ldif
         sleep 10
     fi
