@@ -455,7 +455,7 @@ do_entry2text_search(
 	char			*urlprefix
 )
 {
-    int				err, freedn, html;
+    int				err, freedn;
     char			*buf, **fetchattrs, **vals;
     LDAPMessage			*ldmp;
     struct ldap_disptmpl	*tmpl;
@@ -470,8 +470,6 @@ do_entry2text_search(
 	return( err );
     }
 
-    html = ( urlprefix != NULL );
-
     timeout.tv_sec = SEARCH_TIMEOUT_SECS;
     timeout.tv_usec = 0;
 
@@ -1029,7 +1027,7 @@ searchaction( LDAP *ld, char *buf, char *base, LDAPMessage *entry, char *dn,
     char		**members;
     struct berval	**bmembers;
     struct berval	**bvals;
-    char		*value, *filtpattern, *attr, *selectname;
+    char		*value, *filtpattern, *attr;
     char		*retattrs[2], filter[ 256 ];
     LDAPMessage		*ldmp;
     struct timeval	timeout;
@@ -1046,7 +1044,6 @@ searchaction( LDAP *ld, char *buf, char *base, LDAPMessage *entry, char *dn,
     filtpattern = tip->ti_args[ 1 ];
     retattrs[ 0 ] = tip->ti_args[ 2 ];
     retattrs[ 1 ] = NULL;
-    selectname = tip->ti_args[ 3 ];
 
     bvals = NULL;
     if ( attr == NULL ) {
