@@ -852,7 +852,7 @@ dsgw_utf8StrToLower(unsigned char *s)
                 ;
 	    if (!ultp) {		/* out of range */
                 memcpy(lp, p, sz);
-            } if (ultp->upper) {        /* matched */
+            } else if (ultp->upper) {        /* matched */
                 memcpy(lp, ultp->lower, ultp->tsz);
 		sz = ultp->tsz;
             } else {
@@ -870,7 +870,7 @@ dsgw_utf8StrToLower(unsigned char *s)
                 ;
 	    if (!ultp) {		/* out of range */
                 memcpy(lp, p, sz);
-            } if (ultp->upper) {        /* matched */
+            } else if (ultp->upper) {        /* matched */
                 memcpy(lp, ultp->lower, sz);
             } else {
                 memcpy(lp, p, sz);
@@ -1001,7 +1001,7 @@ dsgw_utf8isUpper(unsigned char *s)
              ;
 	if (!ultp) {			/* out of range */
             return 0;
-        } if (ultp->upper) {		/* matched */
+        } else if (ultp->upper) {		/* matched */
             return 1;
         } else {
             return 0;
@@ -1016,7 +1016,7 @@ dsgw_utf8isUpper(unsigned char *s)
              ;
 	if (!ultp) {			/* out of range */
             return 0;
-        } if (ultp->upper) {		/* matched */
+        } else if (ultp->upper) {		/* matched */
             return 1;
         } else {
             return 0;
@@ -1835,7 +1835,7 @@ dsgw_utf8StrToUpper(char *input)
                 ;
 	    if (!ultp) {		/* out of range */
                 memcpy(up, p, sz);
-            } if (ultp->lower) {        /* matched */
+            } else if (ultp->lower) {        /* matched */
                 memcpy(up, ultp->upper, ultp->tsz);
 		sz = ultp->tsz;
             } else {
@@ -1853,7 +1853,7 @@ dsgw_utf8StrToUpper(char *input)
                 ;
 	    if (!ultp) {	/* out of range */
                 memcpy(up, p, sz);
-            } if (ultp->lower) {        /* matched */
+            } else if (ultp->lower) {        /* matched */
                 memcpy(up, ultp->upper, sz);
             } else {
                 memcpy(up, p, sz);
@@ -1984,7 +1984,7 @@ dsgw_utf8isLower(unsigned char *s)
              ;
 	if (!ultp) {		/* out of range */
             return 0;
-        } if (ultp->lower) {	/* matched */
+        } else if (ultp->lower) {	/* matched */
             return 1;
         } else {
             return 0;
